@@ -5,36 +5,37 @@
 
 eventEval <- function(
     detections,             # Can be a detection object, data frame, or path to csv file
-    what="detections",      # If detections is a detection object specify 'peaks' or 'detections'
+    what = "detections",      # If detections is a detection object specify 'peaks' or 'detections'
     which.one,              # Specify by name or number of which template results to check
     standard,               # File path or data frame of verified detections
-    score.cutoff=11,        # Or specify a score cutoff
-    tol=1                   # Tolerance of time mismatch; +/- 0.5 * tol seconds from center time
+    score.cutoff = 11,        # Or specify a score cutoff
+    tol = 1                   # Tolerance of time mismatch; +/- 0.5 * tol seconds from center time
     ){
     
     # cut the tolerance value in half to produce a +/- time buffer
     tol <- 0.5*tol
     # Some minor class checking to extract the detection data
-    if(class(detections) == "detectionList") {
+    if(inherits(detections, "detectionList")) {
         dbDetect <- FALSE
         if(tolower(what) %in% c("detections", "d", "det", "hits")) {getter <- "getDetections"
         } else if(tolower(what) %in% c("peaks", "p", "pks")) getter <- "getPeaks"
         if(missing(which.one) || length(which.one)>1) {stop("Specify 1 'which.one'.")
-        } else detections <- do.call(getter, list(detection.obj=detections, which.one=which.one))
+        } else detections <- do.call(getter, list(detection.obj = detections, which.one = which.one))
         detections <- detections[detections['template'] == which.one, ]
-    } else if(class(detections) == "data.frame") {
+    } else if(inherits(detections, "data.frame")) {
         if(all(c("fldTime", "fldScore") %in% names(detections))) {dbDetect <- TRUE
         } else if(all(c("time", "score") %in% names(detections))) dbDetect <- FALSE
-    } else if(class(detections) == "character") {
+    } else if(inherits(detections, "character")) {
         if(tolower(gsub(".*\\.", "", detections)) == 'csv') detections <- read.csv(detections)
         else stop("'detections' must be a detectionList object, a file path to a csv file with a recognizable format, or data frame with a recognizable format.")
         # Check to see if detections were originally from the database
         if("fldTime" %in% names(detections)) {dbDetect <- TRUE
         } else stop('Detections must either be a detectionList object or an equivalent data frame (e.g. from the database).')
-    } else if(class(detections) != "data.frame" || all(!c("fldTime", "time", "template") %in% names(detections))) stop("'detections' must be a detectionList object, a file path to a csv file with a recognizeable format, or data frame with a recognizeable format.")
+    } else if(!inherits(detections, "data.frame") || all(!c("fldTime", "time", "template") %in% names(detections))) stop("'detections' must be a detectionList object, a file path to a csv file with a recognizeable format, or data frame with a recognizeable format.")
     # Some minor class checking to read in the standard
-    if(class(standard) == "character") {detections <- read.csv(standard)
-    } else if(class(standard) != "data.frame") stop("'standard' must be a file path or a data frame.")
+    if(inherits(standard, "character")) {
+        detections <- read.csv(standard)
+    } else if(!inherits(standard, "data.frame")) stop("'standard' must be a file path or a data frame.")
     # Check to see if standard was originally from the database
     if(all(c("fldTime", "fldTemplateName") %in% names(standard))) {dbStandard <- TRUE
     } else if(all(c("start.time", "name") %in% names(standard))) {dbStandard <- FALSE
@@ -55,7 +56,7 @@ eventEval <- function(
             sc.fld <- "score"
         } else survey.incl <- FALSE
         outcome <- rep("TRUE -", nrow(detections))
-        outcome[which(detections[, sc.fld]>=score.cutoff)] <- "FALSE +"
+        outcome[which(detections[, sc.fld]>= score.cutoff)] <- "FALSE +"
     } else if (any(nrow(detections) == 0, is.null(nrow(detections)))) {
         return(data.frame())
     } else {
@@ -130,9 +131,9 @@ eventEval <- function(
 		    # Detected but don't exceed score cutoff
 		    } else if(!manual[x] && any(all(same1above[x], manual.above[x]), all(same1below[x], manual.below[x])) && detections[x, sc.fld]<score.cutoff) {vect[x] <- "FALSE -"
 		    # Detected, exceed score cutoff
-		    } else if(!manual[x] && any(all(same1above[x], manual.above[x]), all(same1below[x], manual.below[x])) && detections[x, sc.fld]>=score.cutoff) {vect[x] <- "TRUE +"
+		    } else if(!manual[x] && any(all(same1above[x], manual.above[x]), all(same1below[x], manual.below[x])) && detections[x, sc.fld]>= score.cutoff) {vect[x] <- "TRUE +"
 		    # Detection exceeding score cutoff not in standard
-		    } else if(all(!manual[x], !same1above[x], !same1below[x]) && detections[x, sc.fld]>=score.cutoff) {vect[x] <- "FALSE +"
+		    } else if(all(!manual[x], !same1above[x], !same1below[x]) && detections[x, sc.fld]>= score.cutoff) {vect[x] <- "FALSE +"
 		    # Detection not exceeding score cutoff & not in standard
 		    } else if(all(!manual[x], !same1above[x], !same1below[x]) && detections[x, sc.fld]<score.cutoff) {vect[x] <- "TRUE -"
 		    # If above was changed to all(!manual[x], !manual[x-1], !manual[x+1]) would the rest be necessary?
