@@ -3,59 +3,65 @@
 
 makeBinTemplate <-
 function(
-   clip,               # File path to wav or mp3 file, or a list of exactly two file paths
-   t.lim=NA,           # Length two vector of time limits of spectrogram plot or template, or a list of exactly two such vectors
-   frq.lim=c(0, 12),    # Frequency limits of spectrogram plot or template 
-   select="auto",      # How should points be selected? Options are "cell" or "click" (the same), "rectangle", "auto"
-   binary=TRUE,        # True for a binary plot with high and low amplitude cells
-   buffer=0,           # Buffer around "on" points for "rectangle" and "auto"
-   dens=1,             # Density of points included with "rectangle" and "auto" (fraction of 1)
-   score.cutoff=12,    # Score cutoff for template
-   name="A",           # Name of template
-   comment="", 
-   amp.cutoff="i",     # "i" for interactive, otherwise, a length-one numeric vector
-   shift="i",          # Forward shift for the second clip, to align with the first, in time bins, or "i" for interactive
-   high.pass=-Inf,     # Sets all amplitudes below this frequency to minimum
-   spec.col=gray.3(),  # Color palette for spectrogram when binary=FALSE
-   bin.col=c("white", "black"), # Colors for binary plot
-   quat.col=c("white", "gray40", "gray75", "black"), # Colors for quaternary plot (two clips)
-   sel.col=c("orange", "blue"), # Colors for selected points (on, off)
-   legend.bg.col="#2E2E2E94", # Legend background color
-   legend.text.col="black", # Legend text color
-   wl=512,             # Window length for spectro
-   ovlp=0,             # % overlap between windows for spectro
-   wn="hanning",       # Window type for spectro
-   write.wav=FALSE,    # Set to TRUE to allow writing clip wave objects to file
+   clip,                 # File path to wav or mp3 file, or a list of exactly two file paths
+   t.lim = NA,           # Length two vector of time limits of spectrogram plot or template, or a list of exactly two such vectors
+   frq.lim = c(0, 12),   # Frequency limits of spectrogram plot or template 
+   select = "auto",      # How should points be selected? Options are "cell" or "click" (the same), "rectangle", "auto"
+   binary = TRUE,        # True for a binary plot with high and low amplitude cells
+   buffer = 0,           # Buffer around "on" points for "rectangle" and "auto"
+   dens = 1,             # Density of points included with "rectangle" and "auto" (fraction of 1)
+   score.cutoff = 12,    # Score cutoff for template
+   name = "A",           # Name of template
+   comment = "", 
+   amp.cutoff = "i",     # "i" for interactive, otherwise, a length-one numeric vector
+   shift = "i",          # Forward shift for the second clip, to align with the first, in time bins, or "i" for interactive
+   high.pass = -Inf,     # Sets all amplitudes below this frequency to minimum
+   spec.col = gray.3(),  # Color palette for spectrogram when binary = FALSE
+   bin.col = c("white", "black"), # Colors for binary plot
+   quat.col = c("white", "gray40", "gray75", "black"), # Colors for quaternary plot (two clips)
+   sel.col = c("orange", "blue"), # Colors for selected points (on, off)
+   legend.bg.col = "#2E2E2E94", # Legend background color
+   legend.text.col = "black", # Legend text color
+   wl = 512,             # Window length for spectro
+   ovlp = 0,             # % overlap between windows for spectro
+   wn = "hanning",       # Window type for spectro
+   write.wav = FALSE,    # Set to TRUE to allow writing clip wave objects to file
    ...                 # Additional arguments to spectro
 ){
 
    # Check some arguments
    if(!binary & sum(grepl(select, c("rectangle", "automatic"))) != 0) { 
-      warning("binary adjusted to TRUE for select=\"rectangle\" or select=\"auto\"", immediate.=TRUE)
+      warning("binary adjusted to TRUE for select = \"rectangle\" or select = \"auto\"", immediate. = TRUE)
       binary <- TRUE
    }
    if(!binary & buffer>0) 
-      warning("buffer argument ignored unless binary=TRUE", immediate.=TRUE)
+      warning("buffer argument ignored unless binary = TRUE", immediate. = TRUE)
    if(select%in%c("cell", "click") & dens<1) 
-      warning("dens argument ignored for select=\"click\"", immediate.=TRUE)
+      warning("dens argument ignored for select = \"click\"", immediate. = TRUE)
    if(dens<0.0001 | dens>1) {
-      warning("dens adjusted to 1.0", immediate.=TRUE)
+      warning("dens adjusted to 1.0", immediate. = TRUE)
       dens <- 1
    }
    if(length(clip) == 2 & !binary)
-      warning("binary adjusted to TRUE for two clips", immediate.=TRUE)
-   if(class(amp.cutoff) != "numeric" & amp.cutoff != "i") {
-      warning("amp.cutoff value not recognized, so set to \"i\" for interactive", immediate.=TRUE)
-      amp.cutoff="i"
+      warning("binary adjusted to TRUE for two clips", immediate. = TRUE)
+   if(!inherits(amp.cutoff, "numeric") & amp.cutoff != "i") {
+      warning("amp.cutoff value not recognized, so set to \"i\" for interactive", immediate. = TRUE)
+      amp.cutoff = "i"
    }
-   if(class(shift) != "numeric" & shift != "i") {
-      warning("shift value not recognized, so set to \"i\" for interactive", immediate.=TRUE)
-      shift="i"
+   if(!inherits(shift, "numeric") & shift != "i") {
+      warning("shift value not recognized, so set to \"i\" for interactive", immediate. = TRUE)
+      shift = "i"
    }
    if(!select%in%c("cell", "click", "auto", "rectangle", "rect")) stop("select argument, ", select, ", not recognized")
 
    # Creates a wav file for any clip elements that are not already files
-   clip <- getClip(clip, name=deparse(substitute(clip)), write.wav=write.wav)
+   clip <- getClip(clip, name = deparse(substitute(clip)), write.wav = write.wav)
+
+   #if (!write.wav) {
+   #  clipnow <- clip
+   #  # Below might throw error with more than 1 clip
+   #  on.exit(file.remove(clipnow))
+   #}
 
 ##### Single clip ##### 
    if(length(clip) == 1) { 
@@ -66,12 +72,12 @@ function(
       if(is.na(t.lim[1])) {
 	t.lim <- c(0, Inf) 
       } else {
-	  clip <- cutWave(clip, from=t.lim[1], to=t.lim[2])
+	  clip <- cutWave(clip, from = t.lim[1], to = t.lim[2])
       }
       samp.rate <- clip@samp.rate
       first.t.bin <- t.lim[1]
       # Fourier transform
-      fspec <- spectro(wave=clip, wl=wl, ovlp=ovlp, wn=wn, ...)
+      fspec <- spectro(wave = clip, wl = wl, ovlp = ovlp, wn = wn, ...)
       
       # Sort out time and frequency bins
       t.bins <- fspec$time
@@ -86,7 +92,7 @@ function(
       amp[frq.bins<high.pass, ] <- min(c(amp))
 
       # Create empty amplitude matrices for plotting
-      on.mat <- off.mat <- matrix(0, nrow=n.frq.bins, ncol=n.t.bins)
+      on.mat <- off.mat <- matrix(0, nrow = n.frq.bins, ncol = n.t.bins)
 
       # Bin steps
       t.step <- t.bins[2]-t.bins[1]
@@ -100,17 +106,17 @@ function(
          select.cutoff <- FALSE
 
       # Make plot
-      oldpar <- par(mar=c(5, 4,4, 4))
+      oldpar <- par(mar = c(5, 4,4, 4))
 
       # Color ramp plot
       if(!binary) {
-        image(x=which.t.bins, y=which.frq.bins, t(amp), col=spec.col, xlab="Time (s)", ylab="Frequency (kHz)", las=1, useRaster=TRUE, axes=FALSE, las=1)
-        t.bin.ticks <- pretty(t.bins, n=6)
-        axis(1, at=t.bin.ticks/t.step, labels=t.bin.ticks+t.lim[1])
-        frq.bin.ticks <- pretty(frq.bins, n=6)
-        axis(2, at=frq.bin.ticks/frq.step, labels=frq.bin.ticks, las=1)
+        image(x = which.t.bins, y = which.frq.bins, t(amp), col = spec.col, xlab = "Time (s)", ylab = "Frequency (kHz)", las = 1, useRaster = TRUE, axes = FALSE, las = 1)
+        t.bin.ticks <- pretty(t.bins, n = 6)
+        axis(1, at = t.bin.ticks/t.step, labels = t.bin.ticks+t.lim[1])
+        frq.bin.ticks <- pretty(frq.bins, n = 6)
+        axis(2, at = frq.bin.ticks/frq.step, labels = frq.bin.ticks, las = 1)
         axis(3)
-        axis(4, las=1)
+        axis(4, las = 1)
         box()
       } else {
       # Binary plot, redrawn if amplitude is interactively selected
@@ -120,26 +126,26 @@ function(
            cat("\nEnter l, ll, ll, etc. for lower cutoff, \nh, hh, hhh, etc. for higher cutoff, \nor hit Enter to continue\n") 
         }
         while(y != "") {
-          bin.amp <- matrix(0, nrow=n.frq.bins, ncol=n.t.bins)
+          bin.amp <- matrix(0, nrow = n.frq.bins, ncol = n.t.bins)
           bin.amp[amp>amp.cutoff] <- 1
-          image(x=which.t.bins, y=which.frq.bins, t(bin.amp), col=bin.col, xlab="Time (s)", ylab="Frequency (kHz)", las=1, useRaster=TRUE, axes=FALSE, las=1)
-          legend("topleft", c(paste("Amplitude cutoff: ", amp.cutoff)), bg=legend.bg.col)
-          t.bin.ticks <- pretty(t.bins, n=6)
-          axis(1, at=t.bin.ticks/t.step, labels=t.bin.ticks+t.lim[1])
-          frq.bin.ticks <- pretty(frq.bins, n=6)
-          axis(2, at=frq.bin.ticks/frq.step, labels=frq.bin.ticks, las=1)
+          image(x = which.t.bins, y = which.frq.bins, t(bin.amp), col = bin.col, xlab = "Time (s)", ylab = "Frequency (kHz)", las = 1, useRaster = TRUE, axes = FALSE, las = 1)
+          legend("topleft", c(paste("Amplitude cutoff: ", amp.cutoff)), bg = legend.bg.col)
+          t.bin.ticks <- pretty(t.bins, n = 6)
+          axis(1, at = t.bin.ticks/t.step, labels = t.bin.ticks+t.lim[1])
+          frq.bin.ticks <- pretty(frq.bins, n = 6)
+          axis(2, at = frq.bin.ticks/frq.step, labels = frq.bin.ticks, las = 1)
           axis(3)
-          axis(4, las=1)
+          axis(4, las = 1)
           box()
           # Amplitude cutoff selection
           if(select.cutoff) {
-             cat("\nCurrent cutoff: ", amp.cutoff, "\n", sep="")
-             #cat("\nCurrent cutoff: ", amp.cutoff, ":", sep="")
-             #y <- tolower(scan(n=1, what="character", quiet=TRUE))
-             y <- tolower(readLines(n=1))
+             cat("\nCurrent cutoff: ", amp.cutoff, "\n", sep = "")
+             #cat("\nCurrent cutoff: ", amp.cutoff, ":", sep = "")
+             #y <- tolower(scan(n = 1, what = "character", quiet = TRUE))
+             y <- tolower(readLines(n = 1))
              #if(length(y) == 1) 
              if(y != "") 
-                amp.cutoff <- switch(y, 0,"l"=-1, "ll"=-3, "lll"=-6, "llll"=-10, "lllll"=-20, "llllll"=-30, "h"=1, "hh"=3, "hhh"=6, "hhhh"=10, "hhhhh"=20, "hhhhhh"=30) + amp.cutoff
+                amp.cutoff <- switch(y, 0,"l" = -1, "ll" = -3, "lll" = -6, "llll" = -10, "lllll" = -20, "llllll" = -30, "h" = 1, "hh" = 3, "hhh" = 6, "hhhh" = 10, "hhhhh" = 20, "hhhhhh" = 30) + amp.cutoff
           } else 
              y <- ""
         }
@@ -156,22 +162,22 @@ function(
       if(select%in%c("cell", "click")) {
          # Plot over legend
          if(!binary)
-            image(x=which.t.bins, y=which.frq.bins, t(amp), col=spec.col, add=TRUE)
+            image(x = which.t.bins, y = which.frq.bins, t(amp), col = spec.col, add = TRUE)
          else
-            image(x=which.t.bins, y=which.frq.bins, t(bin.amp), col=bin.col, zlim=c(0, 1), add=TRUE)
+            image(x = which.t.bins, y = which.frq.bins, t(bin.amp), col = bin.col, zlim = c(0, 1), add = TRUE)
          # Select "on" points
          i <- 0
          pts <- NULL
          pos <- NULL
          while(!is.null(pos)|i == 0) {
             i <- i + 1
-            pos <- locator(n=1)
+            pos <- locator(n = 1)
             if(!is.null(pos)) pos <- lapply(pos, round)
             if(!is.null(pos)) pos$y <- pos$y - min(which.frq.bins) + 1
             pts <- rbind(pts, as.numeric(pos))
-            on.mat[pts[, 2:1, drop=FALSE]] <- 1
+            on.mat[pts[, 2:1, drop = FALSE]] <- 1
             # Add points to plot
-            image(x=which.t.bins, y=which.frq.bins, t(on.mat), col=c("transparent", sel.col[1]), zlim=c(0, 1), add=TRUE)
+            image(x = which.t.bins, y = which.frq.bins, t(on.mat), col = c("transparent", sel.col[1]), zlim = c(0, 1), add = TRUE)
             if(!is.null(pos)) 
                cat("\n", nrow(pts), " selected")
          } 
@@ -191,13 +197,13 @@ function(
          pos <- NULL
          while(!is.null(pos)|i == 0) {
             i <- i + 1
-            pos <- locator(n=1)
+            pos <- locator(n = 1)
             if(!is.null(pos)) pos <- lapply(pos, round)
             if(!is.null(pos)) pos$y <- pos$y - min(which.frq.bins) + 1
             pts <- rbind(pts, as.numeric(pos))
-            off.mat[pts[, 2:1, drop=FALSE]] <- 1
+            off.mat[pts[, 2:1, drop = FALSE]] <- 1
             # Add points to plot
-            image(x=which.t.bins, y=which.frq.bins, t(off.mat), col=c("transparent", sel.col[2]), zlim=c(0, 1), add=TRUE)
+            image(x = which.t.bins, y = which.frq.bins, t(off.mat), col = c("transparent", sel.col[2]), zlim = c(0, 1), add = TRUE)
             if(!is.null(pos)) 
                cat("\n", nrow(pts), " selected")
          } 
@@ -210,7 +216,7 @@ function(
          # Rectangular selection
          cat("\nRectangular selection\n")
          # Plot over legend
-         image(x=which.t.bins, y=which.frq.bins, t(bin.amp), col=bin.col, zlim=c(0, 1), add=TRUE)
+         image(x = which.t.bins, y = which.frq.bins, t(bin.amp), col = bin.col, zlim = c(0, 1), add = TRUE)
          i <- 0
          pos1 <- pt.on <- NULL
          while(!is.null(pos1)|i == 0) {
@@ -221,12 +227,12 @@ function(
               cat("\nSelect upper left corner of \"on\" rectangle with a left click.\nPress \'ESC\' to continue.\n")
 	    }
             i <- i + 1
-            pos1 <- locator(n=1)
-            points(pos1$x, pos1$y, pch=22, cex=0.5, col="red", bg="red")
+            pos1 <- locator(n = 1)
+            points(pos1$x, pos1$y, pch = 22, cex = 0.5, col = "red", bg = "red")
             if(!is.null(pos1)) {
                cat("\nSelect lower right corner of \"on\" rectangle with a left click.\n")
-               pos2 <- locator(n=1)
-               points(pos2$x, pos2$y, pch=22, cex=0.5, col="red", bg="red")
+               pos2 <- locator(n = 1)
+               points(pos2$x, pos2$y, pch = 22, cex = 0.5, col = "red", bg = "red")
 
                # First find positions within the matrix that are within the rectangle
                frq.in.rect <- which.frq.bins<pos1$y & which.frq.bins>pos2$y
@@ -239,16 +245,16 @@ function(
                on.mat[temp.mat == 1] <- 1
 
                # Then find locations of all high amplitude cells within rectangle
-               pts <- which(on.mat == 1, arr.ind=TRUE)
+               pts <- which(on.mat == 1, arr.ind = TRUE)
                pts <- pts[, 2:1]
                colnames(pts) <- c("t", "frq")
                pts[, "frq"] <- pts[, "frq"] + min(which.frq.bins) - 1
                pt.on <- rbind(pt.on, pts)
 
                # Plot over rectangle corners
-               image(x=which.t.bins, y=which.frq.bins, t(bin.amp), col=bin.col, zlim=c(0, 1), add=TRUE)
+               image(x = which.t.bins, y = which.frq.bins, t(bin.amp), col = bin.col, zlim = c(0, 1), add = TRUE)
                # Add points to plot
-               image(x=which.t.bins, y=which.frq.bins, t(on.mat), col=c("transparent", sel.col[1]), zlim=c(0, 1), add=TRUE)
+               image(x = which.t.bins, y = which.frq.bins, t(on.mat), col = c("transparent", sel.col[1]), zlim = c(0, 1), add = TRUE)
             }
             pt.on <- unique(pt.on)
          }
@@ -263,13 +269,13 @@ function(
               cat("\nSelect upper left corner of \"off\" rectangle with a left click.\nPress \'ESC\' to continue.\n")
 	    }
             i <- i + 1
-            pos1 <- locator(n=1)
-            points(pos1$x, pos1$y, pch=22, cex=0.5, col="red", bg="red")
+            pos1 <- locator(n = 1)
+            points(pos1$x, pos1$y, pch = 22, cex = 0.5, col = "red", bg = "red")
             if(!is.null(pos1)) {
                #message()
                cat("\nSelect lower right corner of \"off\" rectangle with a left click.\n")
-               pos2 <- locator(n=1)
-               points(pos2$x, pos2$y, pch=22, cex=0.5, col="red", bg="red")
+               pos2 <- locator(n = 1)
+               points(pos2$x, pos2$y, pch = 22, cex = 0.5, col = "red", bg = "red")
 
                # First find positions within the matrix that are within the rectangle
                frq.in.rect <- which.frq.bins<pos1$y & which.frq.bins>pos2$y
@@ -277,7 +283,7 @@ function(
                
                # Find cells with high binary cells within buffer distance--these will have 0 in buff.amp
                # This loop is a bit slow
-               buff.amp <- matrix(TRUE, nrow=n.frq.bins, ncol=n.t.bins)
+               buff.amp <- matrix(TRUE, nrow = n.frq.bins, ncol = n.t.bins)
                if(buffer>0) {
                   for(i in 1:n.frq.bins) {
                      for(j in 1:n.t.bins) {
@@ -295,17 +301,17 @@ function(
                off.mat[temp.mat == 0 & buff.amp] <- 1 
 
                # Then find locations of cells
-               pts <- which(off.mat == 1, arr.ind=TRUE)
+               pts <- which(off.mat == 1, arr.ind = TRUE)
                pts <- pts[, 2:1]
                colnames(pts) <- c("t", "frq")
                pts[, "frq"] <- pts[, "frq"] + min(which.frq.bins) - 1
                pt.off <- rbind(pt.off, pts)
 
                # Plot over rectangle corners
-               image(x=which.t.bins, y=which.frq.bins, t(bin.amp), col=bin.col, zlim=c(0, 1), add=TRUE)
+               image(x = which.t.bins, y = which.frq.bins, t(bin.amp), col = bin.col, zlim = c(0, 1), add = TRUE)
                # Add points to plot
-               image(x=which.t.bins, y=which.frq.bins, t(on.mat), col=c("transparent", sel.col[1]), zlim=c(0, 1), add=TRUE)
-               image(x=which.t.bins, y=which.frq.bins, t(off.mat), col=c("transparent", sel.col[2]), zlim=c(0, 1), add=TRUE)
+               image(x = which.t.bins, y = which.frq.bins, t(on.mat), col = c("transparent", sel.col[1]), zlim = c(0, 1), add = TRUE)
+               image(x = which.t.bins, y = which.frq.bins, t(off.mat), col = c("transparent", sel.col[2]), zlim = c(0, 1), add = TRUE)
             }
             pt.off <- unique(pt.off)
          } 
@@ -314,14 +320,14 @@ function(
          cat("\nAutomatic point selection.\n")
 
          # Plot over legend
-         image(x=which.t.bins, y=which.frq.bins, t(bin.amp), col=bin.col, zlim=c(0, 1), add=TRUE)
+         image(x = which.t.bins, y = which.frq.bins, t(bin.amp), col = bin.col, zlim = c(0, 1), add = TRUE)
 
          # On cells first
          # Set cells that meet criteria to 1 in on.mat, incorporating random cell selection from among these cells based on dens
          on.mat[bin.amp == 1] <- sample(c(1, 0), sum(bin.amp == 1), TRUE, c(dens, 1-dens))
 
          # Then find locations of all high binary cells 
-         pts <- which(on.mat == 1, arr.ind=TRUE)
+         pts <- which(on.mat == 1, arr.ind = TRUE)
          pts <- pts[, 2:1]
          colnames(pts) <- c("t", "frq")
          pts[, "frq"] <- pts[, "frq"] + min(which.frq.bins) - 1
@@ -329,7 +335,7 @@ function(
 
          # Off cells next
          # Find cells with high binary cells within buffer distance--these will have FALSE in buff.amp
-         buff.amp <- matrix(TRUE, nrow=n.frq.bins, ncol=n.t.bins)
+         buff.amp <- matrix(TRUE, nrow = n.frq.bins, ncol = n.t.bins)
          if(buffer>0) {
             for(i in 1:n.frq.bins) {
                for(j in 1:n.t.bins) {
@@ -345,20 +351,20 @@ function(
          off.mat[bin.amp == 0 & buff.amp] <- sample(c(1, 0), sum(bin.amp == 0 & buff.amp), TRUE, c(dens, 1-dens)) # Here 1 in off.mat means cell is "off" cell
 
          # Then find locations of all low binary cells 
-         pts <- which(off.mat == 1, arr.ind=TRUE)
+         pts <- which(off.mat == 1, arr.ind = TRUE)
          pts <- pts[, 2:1]
          colnames(pts) <- c("t", "frq")
          pts[, "frq"] <- pts[, "frq"] + min(which.frq.bins) - 1
          pt.off <- pts
 
          # Add points to plot
-         image(x=which.t.bins, y=which.frq.bins, t(on.mat), col=c("transparent", sel.col[1]), zlim=c(0, 1), add=TRUE)
-         image(x=which.t.bins, y=which.frq.bins, t(off.mat), col=c("transparent", sel.col[2]), zlim=c(0, 1), add=TRUE)
+         image(x = which.t.bins, y = which.frq.bins, t(on.mat), col = c("transparent", sel.col[1]), zlim = c(0, 1), add = TRUE)
+         image(x = which.t.bins, y = which.frq.bins, t(off.mat), col = c("transparent", sel.col[2]), zlim = c(0, 1), add = TRUE)
       }
    } else if(length(clip) == 2) {
 ##### Two clips ##### 
       if(is.na(t.lim[1])) t.lim <- list(NA, NA)
-      if(class(t.lim) != "list") stop("Supplied two clips, so t.lim must be a list of length 2.")
+      if(!inherits(t.lim, "list")) stop("Supplied two clips, so t.lim must be a list of length 2.")
 #      if(class(t.lim) != "list" || length(t.lim) != 2) stop("Supplied two clips, so t.lim must be a list of length 2.")
       clip.path <- clip[[2]]
       first.t.bin <- t.lim[[2]][2]
@@ -371,11 +377,11 @@ function(
          # Trim clip[[i]]
          if(is.na(t.lim[[i]][1])) 
             t.lim[[i]] <- c(0, Inf) else  
-            clip[[i]] <- cutWave(clip[[i]], from=t.lim[[i]][1], to=t.lim[[i]][2])
+            clip[[i]] <- cutWave(clip[[i]], from = t.lim[[i]][1], to = t.lim[[i]][2])
          samp.rate[[i]] <- clip[[i]]@samp.rate
 
          # Fourier transform
-         fspec[[i]] <- spectro(wave=clip[[i]], wl=wl, ovlp=ovlp, wn=wn, ...)
+         fspec[[i]] <- spectro(wave = clip[[i]], wl = wl, ovlp = ovlp, wn = wn, ...)
          
          # Filter amplitudes 
          t.bins[[i]] <- fspec[[i]]$time
@@ -403,12 +409,12 @@ function(
       if(n.t.bins[[1]] > n.t.bins[[2]]) {
          t.bins <- t.bins[[1]]
          which.t.bins <- which.t.bins[[1]]
-         zero.mat <- matrix(min(c(amp[[2]])), nrow=n.frq.bins, ncol=n.t.bins[[1]] - n.t.bins[[2]])
+         zero.mat <- matrix(min(c(amp[[2]])), nrow = n.frq.bins, ncol = n.t.bins[[1]] - n.t.bins[[2]])
          amp[[2]] <- cbind(amp[[2]], zero.mat)
       } else if(n.t.bins[[2]] > n.t.bins[[1]]) {
          t.bins <- t.bins[[2]]
          which.t.bins <- which.t.bins[[2]]
-         zero.mat <- matrix(min(c(amp[[1]])), nrow=n.frq.bins, ncol=n.t.bins[[2]] - n.t.bins[[1]])
+         zero.mat <- matrix(min(c(amp[[1]])), nrow = n.frq.bins, ncol = n.t.bins[[2]] - n.t.bins[[1]])
          amp[[1]] <- cbind(amp[[1]], zero.mat)
       } else {
          t.bins <- t.bins[[1]]
@@ -426,7 +432,7 @@ function(
       } else select.cutoff <- FALSE
 
       # Make plot
-      oldpar <- par(mar=c(5, 4,4, 4))
+      oldpar <- par(mar = c(5, 4,4, 4))
 
       # First plot for selecting cutoff
       x <- 0
@@ -438,7 +444,7 @@ function(
         # Create matrices of on/off data from amplitude data
         bin.amp <- list()
         for(i in 1:2) {
-           bin.amp[[i]] <- matrix(0, nrow=nrow(amp[[i]]), ncol=ncol(amp[[i]]))
+           bin.amp[[i]] <- matrix(0, nrow = nrow(amp[[i]]), ncol = ncol(amp[[i]]))
            bin.amp[[i]][amp[[i]]>amp.cutoff] <- i
         }
         # mat3 is main plotted matrix. Key to mat3: 1 = clip 1 above cutoff, 2 = clip 2 above cutoff, 3 = both clips above cutoff, 0 = no clips above cutoff
@@ -446,23 +452,23 @@ function(
         n.on <- sum(mat3 == 3)
         n.off <- sum(mat3 == 0)
         # First plot
-        image(x=which.t.bins, y=which.frq.bins, t(mat3), col=quat.col, zlim=c(0, 3), xlab="Time (s)", ylab="Frequency (kHz)", useRaster=TRUE, axes=FALSE)
-        legend("topleft", c(paste("Shift", ifelse(is.numeric(shift), shift, 0)), paste("No. overlapped cells", n.on), paste("No. empty cells", n.off), paste("Amplitude cutoff", amp.cutoff)), text.col=legend.text.col, bg=legend.bg.col)
-        t.bin.ticks <- pretty(t.bins, n=6)
-        axis(1, at=t.bin.ticks/t.step, labels=t.bin.ticks+t.lim[1])
-        frq.bin.ticks <- pretty(frq.bins, n=6)
-        axis(2, at=frq.bin.ticks/frq.step, labels=frq.bin.ticks, las=1)
+        image(x = which.t.bins, y = which.frq.bins, t(mat3), col = quat.col, zlim = c(0, 3), xlab = "Time (s)", ylab = "Frequency (kHz)", useRaster = TRUE, axes = FALSE)
+        legend("topleft", c(paste("Shift", ifelse(is.numeric(shift), shift, 0)), paste("No. overlapped cells", n.on), paste("No. empty cells", n.off), paste("Amplitude cutoff", amp.cutoff)), text.col = legend.text.col, bg = legend.bg.col)
+        t.bin.ticks <- pretty(t.bins, n = 6)
+        axis(1, at = t.bin.ticks/t.step, labels = t.bin.ticks+t.lim[1])
+        frq.bin.ticks <- pretty(frq.bins, n = 6)
+        axis(2, at = frq.bin.ticks/frq.step, labels = frq.bin.ticks, las = 1)
         axis(3)
-        axis(4, las=1)
+        axis(4, las = 1)
         box()
         # Amplitude cutoff selection
         if(select.cutoff) {
-          cat("\nCurrent cutoff: ", amp.cutoff, "\n", sep="")
+          cat("\nCurrent cutoff: ", amp.cutoff, "\n", sep = "")
           #cat("\nCurrent cutoff: ", amp.cutoff, "\n")
-          #x <- tolower(scan(n=1, what="character", quiet=TRUE))
-          x <- tolower(readLines(n=1))
-          #if(length(x) == 1) amp.cutoff <- switch(x, 0,"l"=-1, "ll"=-3, "lll"=-6, "llll"=-10, "lllll"=-20, "llllll"=-30, "h"=1, "hh"=3, "hhh"=6, "hhhh"=10, "hhhhh"=20, "hhhhhh"=30) + amp.cutoff
-          if(x != "") amp.cutoff <- switch(x, 0,"l"=-1, "ll"=-3, "lll"=-6, "llll"=-10, "lllll"=-20, "llllll"=-30, "h"=1, "hh"=3, "hhh"=6, "hhhh"=10, "hhhhh"=20, "hhhhhh"=30) + amp.cutoff
+          #x <- tolower(scan(n = 1, what = "character", quiet = TRUE))
+          x <- tolower(readLines(n = 1))
+          #if(length(x) == 1) amp.cutoff <- switch(x, 0,"l" = -1, "ll" = -3, "lll" = -6, "llll" = -10, "lllll" = -20, "llllll" = -30, "h" = 1, "hh" = 3, "hhh" = 6, "hhhh" = 10, "hhhhh" = 20, "hhhhhh" = 30) + amp.cutoff
+          if(x != "") amp.cutoff <- switch(x, 0,"l" = -1, "ll" = -3, "lll" = -6, "llll" = -10, "lllll" = -20, "llllll" = -30, "h" = 1, "hh" = 3, "hhh" = 6, "hhhh" = 10, "hhhhh" = 20, "hhhhhh" = 30) + amp.cutoff
         } else x <- ""
       }
 
@@ -478,17 +484,17 @@ function(
       while(length(x)>0) {
          # Shift clips
          if(select.shift) {
-            #x <- tolower(scan(n=1, what="character", quiet=TRUE))
-            x <- tolower(readLines(n=1))
-            #if(length(x) == 1) shift <- switch(x, 0,"l"=-1, "ll"=-3, "lll"=-6, "llll"=-10, "lllll"=-20, "r"=1, "rr"=3, "rrr"=6, "rrrr"=10, "rrrrr"=20) + shift else x <- NULL
-            if(x != "") shift <- switch(x, 0,"l"=-1, "ll"=-3, "lll"=-6, "llll"=-10, "lllll"=-20, "r"=1, "rr"=3, "rrr"=6, "rrrr"=10, "rrrrr"=20) + shift else x <- NULL
+            #x <- tolower(scan(n = 1, what = "character", quiet = TRUE))
+            x <- tolower(readLines(n = 1))
+            #if(length(x) == 1) shift <- switch(x, 0,"l" = -1, "ll" = -3, "lll" = -6, "llll" = -10, "lllll" = -20, "r" = 1, "rr" = 3, "rrr" = 6, "rrrr" = 10, "rrrrr" = 20) + shift else x <- NULL
+            if(x != "") shift <- switch(x, 0,"l" = -1, "ll" = -3, "lll" = -6, "llll" = -10, "lllll" = -20, "r" = 1, "rr" = 3, "rrr" = 6, "rrrr" = 10, "rrrrr" = 20) + shift else x <- NULL
          } else x <- NULL
          if(shift<0) {
-            zero.mat <- matrix(0, nrow=n.frq.bins, ncol=-shift)
+            zero.mat <- matrix(0, nrow = n.frq.bins, ncol = -shift)
             mat1 <- cbind(zero.mat, bin.amp[[1]])
             mat2 <- cbind(bin.amp[[2]], zero.mat)
          } else if(shift>0) {
-            zero.mat <- matrix(0, nrow=n.frq.bins, ncol=shift)
+            zero.mat <- matrix(0, nrow = n.frq.bins, ncol = shift)
             mat1 <- cbind(bin.amp[[1]], zero.mat)
             mat2 <- cbind(zero.mat, bin.amp[[2]])
          } else if(shift == 0) {
@@ -503,19 +509,19 @@ function(
          n.on <- sum(mat3 == 3)
          n.off <- sum(mat3 == 0)
          # Re-create plot
-         image(x=which.t.bins, y=which.frq.bins, t(mat3), col=quat.col, zlim=c(0, 3), xlab="Time (s)", ylab="Frequency (kHz)", useRaster=TRUE, axes=FALSE)
-         legend("topleft", c(paste("Shift", ifelse(is.numeric(shift), shift, 0)), paste("No. overlapped cells", n.on), paste("No. empty cells", n.off), paste("Amplitude cutoff", amp.cutoff)), text.col=legend.text.col, bg=legend.bg.col)
-         t.bin.ticks <- pretty(t.bins, n=6)
-         axis(1, at=t.bin.ticks/t.step, labels=t.bin.ticks+t.lim[1])
-         frq.bin.ticks <- pretty(frq.bins, n=6)
-         axis(2, at=frq.bin.ticks/frq.step, labels=frq.bin.ticks, las=1)
+         image(x = which.t.bins, y = which.frq.bins, t(mat3), col = quat.col, zlim = c(0, 3), xlab = "Time (s)", ylab = "Frequency (kHz)", useRaster = TRUE, axes = FALSE)
+         legend("topleft", c(paste("Shift", ifelse(is.numeric(shift), shift, 0)), paste("No. overlapped cells", n.on), paste("No. empty cells", n.off), paste("Amplitude cutoff", amp.cutoff)), text.col = legend.text.col, bg = legend.bg.col)
+         t.bin.ticks <- pretty(t.bins, n = 6)
+         axis(1, at = t.bin.ticks/t.step, labels = t.bin.ticks+t.lim[1])
+         frq.bin.ticks <- pretty(frq.bins, n = 6)
+         axis(2, at = frq.bin.ticks/frq.step, labels = frq.bin.ticks, las = 1)
          axis(3)
-         axis(4, las=1)
+         axis(4, las = 1)
          box()
       }
 
       # Create empty amplitude matrices for plotting
-      on.mat <- off.mat <- matrix(0, nrow=n.frq.bins, ncol=n.t.bins)
+      on.mat <- off.mat <- matrix(0, nrow = n.frq.bins, ncol = n.t.bins)
 
       # Point-by-point selection
       if(select%in%c("cell", "click")) {
@@ -527,20 +533,20 @@ function(
       }
       if(select%in%c("cell", "click")) {
          # Plot over legend
-         image(x=which.t.bins, y=which.frq.bins, t(mat3), col=quat.col, zlim=c(0, 3), add=TRUE)
+         image(x = which.t.bins, y = which.frq.bins, t(mat3), col = quat.col, zlim = c(0, 3), add = TRUE)
          # Select "on" points
          i <- 0
          pts <- NULL
          pos <- NULL
          while(!is.null(pos)|i == 0) {
             i <- i + 1
-            pos <- locator(n=1)
+            pos <- locator(n = 1)
             if(!is.null(pos)) pos <- lapply(pos, round)
             if(!is.null(pos)) pos$y <- pos$y - min(which.frq.bins) + 1
             pts <- rbind(pts, as.numeric(pos))
-            on.mat[pts[, 2:1, drop=FALSE]] <- 1
+            on.mat[pts[, 2:1, drop = FALSE]] <- 1
             # Add points to plot
-            image(x=which.t.bins, y=which.frq.bins, t(on.mat), col=c("transparent", sel.col[1]), zlim=c(0, 1), add=TRUE)
+            image(x = which.t.bins, y = which.frq.bins, t(on.mat), col = c("transparent", sel.col[1]), zlim = c(0, 1), add = TRUE)
             if(!is.null(pos)) cat("\n", nrow(pts), " selected")
          } 
          pt.on <- pts
@@ -559,13 +565,13 @@ function(
          pos <- NULL
          while(!is.null(pos)|i == 0) {
             i <- i + 1
-            pos <- locator(n=1)
+            pos <- locator(n = 1)
             if(!is.null(pos)) pos <- lapply(pos, round)
             if(!is.null(pos)) pos$y <- pos$y - min(which.frq.bins) + 1
             pts <- rbind(pts, as.numeric(pos))
-            off.mat[pts[, 2:1, drop=FALSE]] <- 1
+            off.mat[pts[, 2:1, drop = FALSE]] <- 1
             # Add points to plot
-            image(x=which.t.bins, y=which.frq.bins, t(off.mat), col=c("transparent", sel.col[2]), zlim=c(0, 1), add=TRUE)
+            image(x = which.t.bins, y = which.frq.bins, t(off.mat), col = c("transparent", sel.col[2]), zlim = c(0, 1), add = TRUE)
             if(!is.null(pos)) cat("\n", nrow(pts), " selected")
          } 
          pt.off <- pts
@@ -576,7 +582,7 @@ function(
       } else if(select%in%c("rect", "rectangle")) {
          # Rectangular selection
          # Plot over legend
-         image(x=which.t.bins, y=which.frq.bins, t(mat3), col=quat.col, zlim=c(0, 3), add=TRUE)
+         image(x = which.t.bins, y = which.frq.bins, t(mat3), col = quat.col, zlim = c(0, 3), add = TRUE)
          cat("\nRectangular selection\n")
          i <- 0
          pos1 <- pt.on <- NULL
@@ -588,12 +594,12 @@ function(
               cat("\nSelect upper left corner of \"on\" rectangle with a left click.\nPress \'ESC\' to continue.\n")
 	    }
             i <- i + 1
-            pos1 <- locator(n=1)
-            points(pos1$x, pos1$y, pch=22, cex=0.5, col="red", bg="red")
+            pos1 <- locator(n = 1)
+            points(pos1$x, pos1$y, pch = 22, cex = 0.5, col = "red", bg = "red")
             if(!is.null(pos1)) {
                cat("\nSelect lower right corner of \"on\" rectangle with a left click.\n")
-               pos2 <- locator(n=1)
-               points(pos2$x, pos2$y, pch=22, cex=0.5, col="red", bg="red")
+               pos2 <- locator(n = 1)
+               points(pos2$x, pos2$y, pch = 22, cex = 0.5, col = "red", bg = "red")
 
                # First find positions within the matrix that are within the rectangle
                frq.in.rect <- which.frq.bins<pos1$y & which.frq.bins>pos2$y
@@ -606,7 +612,7 @@ function(
                on.mat[temp.mat == 3] <- 1
                
                # Then find locations of all overlapped cells within rectangle
-               pts <- which(on.mat == 1, arr.ind=TRUE)
+               pts <- which(on.mat == 1, arr.ind = TRUE)
                pts <- pts[, 2:1]
                colnames(pts) <- c("t", "frq")
                # Next line should not be necessary here
@@ -615,9 +621,9 @@ function(
                pt.on <- rbind(pt.on, pts)
 
                # Plot over rectangle corners
-               image(x=which.t.bins, y=which.frq.bins, t(mat3), col=quat.col, zlim=c(0, 3), add=TRUE)
+               image(x = which.t.bins, y = which.frq.bins, t(mat3), col = quat.col, zlim = c(0, 3), add = TRUE)
                # Add points to plot
-               image(x=which.t.bins, y=which.frq.bins, t(on.mat), col=c("transparent", sel.col[1]), zlim=c(0, 1), add=TRUE)
+               image(x = which.t.bins, y = which.frq.bins, t(on.mat), col = c("transparent", sel.col[1]), zlim = c(0, 1), add = TRUE)
             }
             pt.on <- unique(pt.on)
          }
@@ -631,12 +637,12 @@ function(
               cat("\nSelect upper left corner of \"off\" rectangle with a left click.\nPress \'ESC\' to continue.\n")
 	    }
             i <- i + 1
-            pos1 <- locator(n=1)
-            points(pos1$x, pos1$y, pch=22, cex=0.5, col="red", bg="red")
+            pos1 <- locator(n = 1)
+            points(pos1$x, pos1$y, pch = 22, cex = 0.5, col = "red", bg = "red")
             if(!is.null(pos1)) {
                cat("\nSelect lower right corner of \"off\" rectangle with a left click.\n")
-               pos2 <- locator(n=1)
-               points(pos2$x, pos2$y, pch=22, cex=0.5, col="red", bg="red")
+               pos2 <- locator(n = 1)
+               points(pos2$x, pos2$y, pch = 22, cex = 0.5, col = "red", bg = "red")
 
                # First find positions within the matrix that are within the rectangle
                frq.in.rect <- which.frq.bins<pos1$y & which.frq.bins>pos2$y
@@ -644,7 +650,7 @@ function(
                
                # Find cells with high binary cells within buffer distance--these will have FALSE in buff.amp
                # This loop is a bit slow
-               buff.amp <- matrix(TRUE, nrow=n.frq.bins, ncol=n.t.bins)
+               buff.amp <- matrix(TRUE, nrow = n.frq.bins, ncol = n.t.bins)
                if(buffer>0) {
                   for(i in 1:n.frq.bins) {
                      for(j in 1:n.t.bins) {
@@ -662,17 +668,17 @@ function(
                off.mat[temp.mat == 0 & buff.amp] <- 1 
                
                # Then find locations of cells
-               pts <- which(off.mat == 1, arr.ind=TRUE)
+               pts <- which(off.mat == 1, arr.ind = TRUE)
                pts <- pts[, 2:1]
                colnames(pts) <- c("t", "frq")
                pts[, "frq"] <- pts[, "frq"] + min(which.frq.bins) - 1
                pt.off <- rbind(pt.off, pts)
 
                # Plot over rectangle corners
-               image(x=which.t.bins, y=which.frq.bins, t(mat3), col=quat.col, zlim=c(0, 3), add=TRUE)
+               image(x = which.t.bins, y = which.frq.bins, t(mat3), col = quat.col, zlim = c(0, 3), add = TRUE)
                # Add points to plot
-               image(x=which.t.bins, y=which.frq.bins, t(on.mat), col=c("transparent", sel.col[1]), zlim=c(0, 1), add=TRUE)
-               image(x=which.t.bins, y=which.frq.bins, t(off.mat), col=c("transparent", sel.col[2]), zlim=c(0, 1), add=TRUE)
+               image(x = which.t.bins, y = which.frq.bins, t(on.mat), col = c("transparent", sel.col[1]), zlim = c(0, 1), add = TRUE)
+               image(x = which.t.bins, y = which.frq.bins, t(off.mat), col = c("transparent", sel.col[2]), zlim = c(0, 1), add = TRUE)
             }
             pt.off <- unique(pt.off)
          } 
@@ -685,7 +691,7 @@ function(
          on.mat[mat3 == 3] <- sample(c(1, 0), sum(mat3 == 3), TRUE, c(dens, 1-dens))
 
          # Then find locations of all high cells 
-         pts <- which(on.mat == 1, arr.ind=TRUE)
+         pts <- which(on.mat == 1, arr.ind = TRUE)
          pts <- pts[, 2:1]
          colnames(pts) <- c("t", "frq")
          pts[, "t"] <- pts[, "t"] + min(which.t.bins) - 1
@@ -695,7 +701,7 @@ function(
          # Off cells next
          # Find cells with high binary cells within buffer distance--these will have FALSE in buff.amp
          # This loop is a bit slow
-         buff.amp <- matrix(TRUE, nrow=n.frq.bins, ncol=n.t.bins)
+         buff.amp <- matrix(TRUE, nrow = n.frq.bins, ncol = n.t.bins)
          if(buffer>0) {
             for(i in 1:n.frq.bins) {
                for(j in 1:n.t.bins) {
@@ -710,7 +716,7 @@ function(
          off.mat[mat3 == 0 & buff.amp] <- sample(c(1, 0), sum(mat3 == 0 & buff.amp), TRUE, c(dens, 1-dens))
                
          # Then find locations of cells
-         pts <- which(off.mat == 1, arr.ind=TRUE)
+         pts <- which(off.mat == 1, arr.ind = TRUE)
          pts <- pts[, 2:1]
          colnames(pts) <- c("t", "frq")
          pts[, "t"] <- pts[, "t"] + min(which.t.bins) - 1
@@ -718,8 +724,8 @@ function(
          pt.off <- pts
 
          # Add points to plot
-         image(x=which.t.bins, y=which.frq.bins, t(on.mat), col=c("transparent", sel.col[1]), zlim=c(0, 1), add=TRUE)
-         image(x=which.t.bins, y=which.frq.bins, t(off.mat), col=c("transparent", sel.col[2]), zlim=c(0, 1), add=TRUE)
+         image(x = which.t.bins, y = which.frq.bins, t(on.mat), col = c("transparent", sel.col[1]), zlim = c(0, 1), add = TRUE)
+         image(x = which.t.bins, y = which.frq.bins, t(off.mat), col = c("transparent", sel.col[2]), zlim = c(0, 1), add = TRUE)
       }
    } else stop("Expected clip length of 1 or 2, but got ", length(clip))
 
@@ -737,9 +743,9 @@ function(
    duration <- n.t.bins*t.step
    frq.lim <- range(pt.on[, "frq"], pt.off[, "frq"])*frq.step
 
-   template <- list(new("binTemplate", clip.path=clip.path, samp.rate=samp.rate, pt.on=pt.on, pt.off=pt.off, t.step=t.step, frq.step=frq.step, n.t.bins=as.integer(n.t.bins), first.t.bin=first.t.bin, n.frq.bins=as.integer(n.frq.bins), duration=duration, frq.lim=frq.lim, wl=as.integer(wl), ovlp=as.integer(ovlp), wn=wn, score.cutoff=score.cutoff, comment=comment))
+   template <- list(new("binTemplate", clip.path = clip.path, samp.rate = samp.rate, pt.on = pt.on, pt.off = pt.off, t.step = t.step, frq.step = frq.step, n.t.bins = as.integer(n.t.bins), first.t.bin = first.t.bin, n.frq.bins = as.integer(n.frq.bins), duration = duration, frq.lim = frq.lim, wl = as.integer(wl), ovlp = as.integer(ovlp), wn = wn, score.cutoff = score.cutoff, comment = comment))
    names(template) <- name
-   template <- new("binTemplateList", templates=template)
+   template <- new("binTemplateList", templates = template)
 
    par(oldpar)
    cat("\nDone.\n")
